// ==UserScript==
// @name				Show availability on the Amazon stores (short version)
// @description			Enabling this option will display availability information at the EPFL Library (paper or online) for titles found on Amazon.
// @author				Thomas Guignard
// @tab					General
// @enabledbydefault	true
// @include				http://www.amazon.com/*
// @include				http://www.amazon.de/*
// @include				http://www.amazon.co.uk/*
// @include				http://www.amazon.fr/*
// @include				http://www.amazon.ca/*
// @require				epflshared.js
// ==/UserScript==

// Version 0.10
// By T. Guignard <thomas.guignard@epfl.ch> - Apr 11
// Originally based upon the Kearney Library extension: https://addons.mozilla.org/fr/firefox/addon/2876

(

function()
{
	
// First, we'll have to handle title pages and pages with mutliple titles differently	
try 
    { var isbn = window.content.location.href.match(/\/(\d{7,9}[\d|X])/)[1];
		//dump('[amazon] Title page with ISBN = ' + isbn + '\n');
		// This works for amazon.de and amazon.fr but NOT for amazon.com	
		//var origTitle = document.evaluate("//b[@class='sans']", document, null, XPathResult.FIRST_ORDERED_NODE_TYPE, null ).singleNodeValue;
		var origTitle = document.getElementById("btAsinTitle");
		//dump('[amazon] Try to insert into = ' + origTitle + '\n');
		try
			{
			libraryLookup(isbn, origTitle);
			}
		catch(e)
			{
			//dump(e + '\n');
			return;
			}
		
	}
catch (e)
    { 
		// If no EAN is found, we're maybe on a search results page, so let's try to handle those as well
		//dump('[amazon] Not a title page.\n');

		// There, one has to hunt for <a class="title"> nodes
		var allLinks = getElementsByClass('title',document,'a');
		//dump('[amazon] 1st round - I found ' + allLinks.length + ' titles here\n');
		
		for (var i = 0; i < allLinks.length; i++) {
			//dump('[amazon] node : ' + allLinks[i] + '\n');
			var thisLink = allLinks[i];
			var thisLinkValue = thisLink.getAttributeNode('href').nodeValue;
			//dump('[amazon] nodeValue : ' + thisLinkValue + '\n');
			try
				{
				var isbn = thisLinkValue.match(/\/(\d{7,9}[\d|X])/)[1];
				//dump('[amazon] Link found with ISBN = ' + isbn + '\n');
				try
					{
					libraryLookup(isbn, allLinks[i].firstChild);
					}
				catch(e)
					{
					//dump(e + '\n');
					return;
					}
				}
			catch(e)
				{
				// Ok, forget this link.
				}
		}
		
		// Unfortunately, some title lists aren't handled that way
		// There, one has to hunt for <tr class="small">
		var allLinks = getElementsByClass('small',document,'tr');
		//dump('[amazon] 2nd round - I found ' + allLinks.length + ' titles here\n');
		
		for (var i = 0; i < allLinks.length; i++) {
			
			var thisLink = allLinks[i].childNodes[3].childNodes[1];
			//dump('[amazon] node : ' + thisLink + '\n');
	
			try
				{
				var thisLinkValue = thisLink.getAttributeNode('href').nodeValue;
				//dump('[amazon] nodeValue : ' + thisLinkValue + '\n');
				
				var isbn = thisLinkValue.match(/\/(\d{7,9}[\d|X])/)[1];
				//dump('[amazon] Link found with ISBN = ' + isbn + '\n');
				try
					{
					libraryLookup(isbn, thisLink);
					}
				catch(e)
					{
					//dump(e + '\n');
					return;
					}
				}
			catch(e)
				{
				// Ok, forget this link.
				}
		}
		
		// Bestseller titles on internation sites are still handled differently
		// There, one has to hunt for <div class="zg_title">
		var allLinks = getElementsByClass('zg_title',document,'div');
		//dump('[amazon] 3rd round - I found ' + allLinks.length + ' titles here\n');
		
		for (var i = 0; i < allLinks.length; i++) {
			
			var thisLink = allLinks[i].childNodes[1];
			//dump('[amazon] node : ' + thisLink + '\n');
	
			try
				{
				var thisLinkValue = thisLink.getAttributeNode('href').nodeValue;
				//dump('[amazon] nodeValue : ' + thisLinkValue + '\n');
				
				var isbn = thisLinkValue.match(/\/(\d{7,9}[\d|X])/)[1];
				//dump('[amazon] Link found with ISBN = ' + isbn + '\n');
				try
					{
					libraryLookup(isbn, thisLink);
					}
				catch(e)
					{
					//dump(e + '\n');
					return;
					}
				}
			catch(e)
				{
				// Ok, forget this link.
				}
		}
		
		// On Amazon.ca, results lists have yet another format
		// There, one has to hunt for <div class="productTitle">
		var allLinks = getElementsByClass('productTitle',document,'div');
		//dump('[amazon] 4th round - I found ' + allLinks.length + ' titles here\n');
		
		for (var i = 0; i < allLinks.length; i++) {
			
			var thisLink = allLinks[i].firstChild;
			//dump('[amazon] node : ' + thisLink + '\n');
			//dump('[amazon] node value : ' + thisLink.nodeValue + '\n');
	
			try
				{
				var thisLinkValue = thisLink.getAttributeNode('href').nodeValue;
				//dump('[amazon] nodeValue : ' + thisLinkValue + '\n');
				
				var isbn = thisLinkValue.match(/\/(\d{7,9}[\d|X])/)[1];
				//dump('[amazon] Link found with ISBN = ' + isbn + '\n');
				try
					{
					libraryLookup(isbn, thisLink);
					}
				catch(e)
					{
					//dump(e + '\n');
					return;
					}
				}
			catch(e)
				{
				// Ok, forget this link.
				}
		}
		
	return; }

}
)();
